Editor Test: Print Plugin

Content before the editor.

# Print Plugin details

1. The print plugin is a small plugin that adds the capability of printing the document in the editor
2. If the underlying browser doesn't support print, then the button will be disabled by default

## Things to test (manually, because of the print dialog, the function test cannot be automated):

1. Verify that clicking the print button opns the browser print dialog and the document will print.
2. Verify that the printed document is only the document in the editor, not the whole page.

Content after the editor.